@@ -36,22 +36,18 @@ class Q_DECL_EXPORT CdmaWidget : public SettingWidget
 {
     Q_OBJECT
 public:
-    explicit CdmaWidget(const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(), QWidget* parent = 0, Qt::WindowFlags f = 0);
+    explicit CdmaWidget(const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(), QWidget *parent = 0, Qt::WindowFlags f = 0);
     virtual ~CdmaWidget();
 
     void loadConfig(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
     void loadSecrets(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
 
-    QVariantMap setting(bool agentOwned = false) const Q_DECL_OVERRIDE;
+    QVariantMap setting() const Q_DECL_OVERRIDE;
 
     virtual bool isValid() const Q_DECL_OVERRIDE;
 
-private Q_SLOTS:
-    void showPassword(bool show);
-    void passwordStorageChanged(int index);
-
 private:
-    Ui::CdmaWidget * m_ui;
+    Ui::CdmaWidget *m_ui;
 };
 
 #endif // PLASMA_NM_CDMA_WIDGET_H
