@@ -35,6 +35,12 @@
 #define NM_L2TP_KEY_GATEWAY           "gateway"
 #define NM_L2TP_KEY_USER              "user"
 #define NM_L2TP_KEY_PASSWORD          "password"
+#define NM_L2TP_KEY_USE_CERT          "use-cert"
+#define NM_L2TP_KEY_CERT_PUB          "cert-pub"
+#define NM_L2TP_KEY_CERT_CA           "cert-ca"
+#define NM_L2TP_KEY_CERT_KEY          "cert-key"
+#define NM_L2TP_KEY_MTU               "mtu"
+#define NM_L2TP_KEY_MRU               "mru"
 #define NM_L2TP_KEY_DOMAIN            "domain"
 #define NM_L2TP_KEY_REFUSE_EAP        "refuse-eap"
 #define NM_L2TP_KEY_REFUSE_PAP        "refuse-pap"
